;;****************************************************************************
;; FileName : WDLIB.H
;; Function : Watch Dog Library of Include File
;; Design's : By Todd
;; BuildDate: 01/10/2002 V1.0
;;****************************************************************************

;;External sub-program as follows:
EXTRN   InitWD:near             ;;Initial watch dog
EXTRN   EnWD:near               ;;Enable watch dog
EXTRN   DisWD:near              ;;Disable watch dog

;;Direct control register for IO SMsC37B787
;;(Referance the detail information of data sheet)
EXTRN   OpenIoConfig:near       ;;Enable register with SMsC37B787
EXTRN   CloseIoConfig:near      ;;Disable register with SMsC37B787
EXTRN   SelectIoDevice:near     ;;Select Watchdog or another device
EXTRN   WriteIoCR:near          ;;Write index data configuration register
EXTRN   ReadIoCR:near           ;;Read index data configuration register

;;Default value define as follows:
equWdUnitS EQU  80h             ;;Watch dog counter value of unit is second
equWdUnitM EQU  00h             ;;Watch dog counter value of unit is minute

;;use sub-program of method as follows:
;;
;;==========================================================================;;
;; OpenIoConfig                                                             ;;
;;==========================================================================;;
;; Function : Enable register with winbond SMsC37B787                       ;;
;; Input    : None                                                          ;;
;; Return   : None                                                          ;;
;; Change   : AL,DX                                                         ;;
;;==========================================================================;;

;;==========================================================================;;
;; CloseIoConfig                                                            ;;
;;==========================================================================;;
;; Function : Disable register with winbond SMsC37B787                      ;;
;; Input    : None                                                          ;;
;; Return   : None                                                          ;;
;; Change   : AL,DX                                                         ;;
;;==========================================================================;;

;;==========================================================================;;
;; SelectIoDevice                                                           ;;
;;==========================================================================;;
;; Function : Select Watchdog or another device                             ;;
;; Input    : AH = select device of function                                ;;
;; Return   : None                                                          ;;
;; Change   : AX,DX                                                         ;;
;;==========================================================================;;

;;==========================================================================;;
;; WriteIoCR                                                                ;;
;;==========================================================================;;
;; Function : Write index data register for SMsC37B787                      ;;
;; Input    : AL = select index port of configuration register(CR)          ;;
;;            AH = configuration register of data                           ;;
;; Return   : None                                                          ;;
;; Change   : AX,DX                                                         ;;
;;==========================================================================;;

;;==========================================================================;;
;; ReadIoCR                                                                 ;;
;;==========================================================================;;
;; Function : Read index data register for SMsC37B787                       ;;
;; Input    : AL = select index port of configuration register(CR)          ;;
;; Return   : AL = configuration register of data                           ;;
;; Change   : AL,DX                                                         ;;
;;==========================================================================;;

;;==========================================================================;;
;; InitWD                                                                   ;;
;;==========================================================================;;
;; Function : Initial watch dog                                             ;;
;; Input    : BL = watch dog counter of unit                                ;;
;;                 00h : minute                                             ;;
;;                 80h : second                                             ;;
;; Return   : None                                                          ;;
;; Change   : None                                                          ;;
;;==========================================================================;;

;;==========================================================================;;
;; EnWD                                                                     ;;
;;==========================================================================;;
;; Function : Enable watch dog                                              ;;
;; Input    : BL = watch dog time out of value                              ;;
;; Return   : None                                                          ;;
;; Change   : None                                                          ;;
;;==========================================================================;;

;;==========================================================================;;
;; DisWD                                                                    ;;
;;==========================================================================;;
;; Function : Disable watch dog                                             ;;
;; Input    : None                                                          ;;
;; Return   : None                                                          ;;
;; Change   : None                                                          ;;
;;==========================================================================;;
